---
home: false
title: Edition Guidelines
layout: Layout
---

# {{ $frontmatter.title }}

All texts in the present archive are reserved under a Creative Commons Licence (CC-BY-SA). These texts were created as XML-files with an own scheme and in following the [Guidelines for Electronic Text Encoding and Interchange (in version P5) of the Text Encoding Initiative (TEI)](http://www.tei-c.org/). However, some of the images were reserved under a Creative Commons Licence (CC-BY-SA), too, while others can be used only with a VPN-connection of the University of Göttingen.

In some cases, we were not able to solve every technical problems in this project phase. These issues will be solved in the next stage and are named at the bottom of this page.

## Format

### Page beginning

```HTML
<pb n="PAGE" facs="TEXTGRID-URI"/>
```

The n attribute hosts the page number, e.g. 2r and sould always start with a digit, followed by "r" (recto") or "v" (verso). When there is a page number available at the source, we copy the value and do not have to add "r" or "v".

Please omit the @facs in the transliteration.

### Empty Pages

Empty pages will be encoded by a sequence of tei:pb elements. If the foliation number omits these pages, we add "+1" to the last number of the original (or archival) foliation.

```HMTL
<pb n="PAGE" facs="TEXTGRID-URI1"/>
<pb n="PAGE" facs="TEXTGRID-URI2"/>
<pb n="PAGE" facs="TEXTGRID-URI3"/>
```

### Special case: Ms. Graffin

In case of Ms. Graffin the manuscript is lost, but we have an edition by Francois Nau in which the page beginnings of the manuscript have been noted. While the page beginnings of the edition are encoded as usual page beginnings, the ones of the lost manuscript are encoded as follows:

```HTML
<note hand="#Nau" type="manuscript_page_beginning">(p. 2)</note>
```

Nau as the one responsible for the addition "(p. 2)" is listed in the `tei:teiHeader` under `tei:editionStmt` as follows

```HTML
<editionStmt>
  <respStmt xml:id="Nau">
      <resp when="1920">Former editor</resp> 
         <persName>François Nau</persName> 
    </respStmt> 
 </editionStmt>
```

### Column beginning

```HTML
<cb/>
```

Every column is marked up at the beginning.

### Line

Every line of text should be represented via

```HTML
<ab>line of text</ab>
```

To encode a blank line (it has to be an intentionally left space between to lines!) the correct encoding is <ab/>

### Verse Line

A verse line, that interrupts the usual prose style, we are using tei:lg for the stanza and tei:l for all lines.

```HTML
<lg> 
    <l>line1</l>
    <l>line2</l>
</lg>
```

### Heading-like structures

When there is a division into different sections, may be not applied to the complete document or not applied homogeneously, we indicate this by NOT using tei:head (what causes other structures to be used in the XML file) and encode this with

```HTML
<ab type="head">section 123</ab>
```

### Lost or damaged areas

If a part of a document is lost or damaged we can use

```HTML
<damage extent="half page">
```

The extent attribute lists the quantity of the lost part like the following:

- one page
- half page
- one line
- two words

When the lost content can be reproduced, Additions by the author can be used.

### Colophon

```HTML
<ab type="colophon">end of the text</ab>
```

There is a corresponding part in the tei:teiHeader, pointing to these lines with a tei:colophon.

### Inline Colophon

```HTML
<ab>and she died. <seg type="colophon">end of the text</seg></ab>
```

### Poetic Colophones

```HTML
<lg type="colophon">
    <l>line 1<l> 
    <l>line 2</l>
  </lg>
```

### Line breaks within markup

Since we have to maintain the hierarchical structure of XML, we have to use use two linked elements for encoding phenomena on different lines like the following example:

```HTML
<ab><persName next="#mss1234_2r_1">-ihA</persName>more text</ab>
<ab><persName xml:id="mss1234_2r_1">rak</persName></ab>
```

Both persNames are linkes so it marks up the same entitry and not two different, or two times the same entity. Please notice the "#" to point to an xml:id. xml:id MUST NOT start with a digit. The structure of the xml:id value is RECOMMENDED as: SIGNATURE-OR-MS-ID_PAGE_NUMBER. Oxygen supports the linking mechanism. When a "#" is typed in, a list with all currently used xml:id shows selectable items.

Word break together with line break

```HTML
<ab>this is my sen</ab>
<ab><lb break="no"/>tence.</ab>
```

## Language

`@xml:lang` will be used to set a language for all descendant XML nodes. We are using a set of 7 values:

- ara (Arabic)
- syc (Classical Syriac)
- eng (English)
- lat (Latin)
- karshuni (Karshuni)
- syc-syrj (Western Syriac)
- syc-syrn (Eastern Syriac)

These values have to be declared in the TEI header as described [here](https://wiki.de.dariah.eu/display/AHK/TEI+Header). They match the `ident` attribute of a `tei:language` declared in the TEI header.

## Textual Content

### Headlines

```HTML
<head>Headline</head>
```

head is to be used without tei:ab.

### Proverbs

```HTML
<quote>It was, so it is not.</quote>
```

Any proverb will be encoded as quotation.

In a longer segment, we have to link the lines with \@next attributes.

```HTML
<ab>some other text<quote next="#prov1">It was,</quote></ab>
<ab><quote xml:id="prov1">so it is not.</quote> an more other text</ab>
```

### Highlighted Parts

Textual content that is highlighted by using a different colour, and underline or other text decoration.

```HTML
<hi rend="underline">highlighted text</hi>
```

The rend attribute MAY contains one or more (separated by whitespace) of the following:

- underline
- color(red) - any color name from [this list](https://www.w3schools.com/colors/colors_names.asp) is applicable, always in lower-case
- italic

### Empty Lines

When a line is left intentionally empty (may be to include text later on) we encode an empty element

```HTML
<ab/>
```

If the reason is unclear we continoue the encoding and set a marker for a pace between two lines

```HTML
<ab>first line</ab> 
<ab rend="margin-top">second line with a space to the next line</ab>
```

### Additions by the editor

Text added by the editor has to be marked up with

```HTML
<supplied>added text</supplied>
```

### Additions by the author

#### Surplus

Text added by the author (e.g. to maintain a justified style) we are using

```HTML
<surplus>additional character or text, may be repeated in the next line</surplus>
```

This element is used for additional text that is in the dpcument for unknown reason.

#### Interlinear or marginal additions

Additions to be read within the text placed around the main part (interlinear, marginal, footer)

```HTML
<add place="margin">addition</add>
```

These parts are encoded at the place where the addition belongs to, to maintain a readable text.

Allowed values in the place attribute:

- margin
- interlinear
- footer
- header
- above
- below

### Deletions

A word, phrase or other part deleted by the author.

```HTML
<del rend="strikethrough">this part is deleted</del>
```

The rend attribute is optional, allowed values are:

- strikethrough

### Abreviations

### Widows and orphans

```HTML
<catchwords>phrase to ensure correct order</catchwords>
```

### Typos

Errors in writing are encoded in a diplomatic way together with a corrected form. The following encoding indicates that the correction has been made by a scribe:

```HTML
<choice><sic>errro</sic><corr>error</corr></choice>
```

If a correction is made by an editor a `resp` attribute has to be added to the tei:corr element pointing to the editors xml:id as named in the tei:teiHeader (tei:editor).

Entry in the teiHeader:

```HTML
<titleStmt>
    <title type="main">The Story and Proverbs of Ahiqar the Wise</title> 
    <editor xml:id="sb">Simon Birol</editor>  
    <editor xml:id="ae">Aly Elrefaei</editor> 
</titleStmt>
```

Encoding of the correction

```HTML
<choice>
    <sic>errro</sic>
    <corr resp="#sb">error</corr>
</choice>

<choice>
    <sic>errro</sic>
    <corr resp="#ae">error</corr>
</choice>
```

Please keep in mind that `tei:choice` needs two child elements.

### Unclear reding

Transcriptions made with a somewhat higher level of uncertainty are marked up with

```HTML
<unclear reason="illegible">not sure if this transcription is correct</unclear>
```

### Glyphs and other characters

For quotation marks the tei:g element is used with a current character that represents the original one.

```HTML
<g>»</g>a quote<g>«</g>
```

### Multilingualism

When words or lines of a text written in a language different from the one specified in a superior `tei:text` element, the language should be marked up.

```HTML
<ab>a sentence <seg xml:lang="ger">mit mehreren</seg> words in German.</ab> 
<ab xml:lang="ger">Wenn ganze Zeilen in einer anderen Sprache stehen.</ab>
```

Any language code used here MUST BE one of the codes mentioned in the section Language.

### Annotations (special case)

Harvard 80 contains several witnesses inside a single document. The copyists notes are separated by `tei:note/@resp` if they can be distinguished. Anonymous writers are marked as "anonym".

```HTML
<ab>
    <note resp="#anonym">another manuscript has added
        <cit type="verbatim">
            <quote><persName>ܣܢܚܪܝܒܼ</persName></quote>
            <bibl type="provided-by-editor" source="#S5">S5</bibl>
        </cit>
    </note>
</add>
```

While the text of the note is a direct child of `tei:note` , the word or phrase "quoted" from the other manuscript(s) are marked with `tei:cit` as described in Quotes and paraphrases of other works.

If the hand has been identified successfully, the `xml:id` given in `@tei:resp` has to be resolved in the TEI header within the element `tei:ms:item` using `tei:respStmt`:

```HTML
<msContents>
    <msItem>
        <textLang>Classical Syriac</textLang>
        <respStmt xml:id="anonym">
            <resp notBefore="1856" notAfter="1913">Scribe</resp>
            <persName>unknown</name>
        </respStmt>
    </msItem>
</msContents>
```

#### Content of other manuscripts mentioned in annotations

In some cases known or unknown annotators add philological information by stating that a certain word or phrase is different in another manuscript. These "quotes" are encoded as `tei:cit` just as described in Quotes and paraphrases of other works.

```HTML
<note>
    [… previous text …]
        <cit type="verbatim">
            <quote><persName>ܣܢܚܪܝܒܼ</persName></quote>
            <bibl type="provided-by-editor" source="#S5">S5</bibl>
        </cit>
</note>
```

#### Enumeration labels

In some manuscripts the proverbs are enumerated. Their labels are encoded with `tei:seg[@type = "label"]`.

```HTML
<ab><seg type="label">1.</seg> Text of the proverb/saying.</ab>
```

### Quotes and paraphrases of other works

In some cases the text of Ahiqar directly quotes or paraphrases other works like the Bible. A short verbal accordance (no more than 2 words) is treated as paraphrase. These occurrences are encoded with `tei:cit` as follows:

#### Quotation

```HTML
<cit type="verbatim">
    <quote>In the beginning God created the heavens and the earth.</quote>
    <bibl type="provided-by-editor" source="#item-in-listBibl">Gen 1,1.</bibl>
 </cit>
```

The source given in `@source` has to be resolved in the TEI header within `listBibl`.

```HTML
<listBibl>
    <bibl xml:id="item-in-listBibl">Some reference.</bibl>
</listBibl>
```

#### Paraphrase

```HTML
<cit type="paraphrase">
    <quote>The fifth dawn was breaking.</quote>
    <note type="original-phrase">And evening passed and morning came, marking the fifth day.</note>
    <bibl type="provided-by-editor" source="#item-in-listBibl">Gen 1,23.</bibl>
</cit>
```

Again, the source given in `@source` has to be resolved in the TEI header within `listBibl` .

```HTML
<listBibl>  <bibl xml:id="item-in-listBibl">Some reference.</bibl> </listBibl>
```

#### If a paraphrase refers to more than one other text

In some cases, a paraphrase alludes more than one other text. In this case we have to make the connection between `tei:note` and `tei:bibl` clear by using the `@corresp` and `@xml:id` attributes.

The following example is taken from SMMJ 162:

```HTML
<cit type="paraphrase">
    <quote xml:id="prov5.1.spr66">ܢܟ̈ܣܐ܂ ܥܕܡܐ ܕܡܹܬܡܲܠܝܐ ܥܦܪܐ܂</quote>
    <note corresp="#Peshitta_Prov_Eccl_etc_Prov_27_20_bibl" type="original-phrase">ܫܝܘܠ ܘܐܒܕܢܐ ܠܐ ܣܒܥܝܢ܂ ܗܟܢܐ ܐܦ ܥܝܢܗܘܢ ܕܒܢ̈ܝ ܐܢܫܐ ܠܐ ܣܒܥܐ</note> 
    <bibl xml:id="Peshitta_Prov_Eccl_etc_Prov_27_20_bibl" type="provided-by-editor" source="#Peshitta_Prov_Eccl_etc">Prov 27,20.</bibl> 
    <note corresp="#Peshitta_Prov_Eccl_etc_Eccl_1_8_bibl" type="original-phrase">ܟܠܗܘܢ ܦܬ̈ܓܡܐ ܠܐܝܢ܂ ܠܐ ܢܣܒܥ ܓܒܪܐ ܠܡܡܠܠܘ܂ ܘܠܐ ܣܒܥܐ ܥܝܢܐ ܠܡܚܙܐ܂ ܘܠܐ ܡܠܝܐ ܐܕܢܐ ܠܡܫܡܥ܂</note>   
    <bibl xml:id="Peshitta_Prov_Eccl_etc_Eccl_1_8_bibl" type="provided-by-editor" source="#Peshitta_Prov_Eccl_etc">Eccl 1,8.</bibl>
</cit>
```

#### Quotes and paraphrases that span more than one line

Quotes and paraphrases aren't restricted to one line but can encompass several ones. The basic mechanism is the same as connecting proverbs with each other via `@next` and `@xml:id` . It is encoded as follows (with a simplified example from SMMJ 162):

```HTML
<ab>
    <cit type="paraphrase" next="#prov5.spr66.2">
        <quote next="#prov5.1.spr66">ܕܒܪܐܢܫܐ ܡܒܘܼܥܐ ܗܝܿ܂ ܘܠܐ ܣܿܒܥܐ</quote>
    </cit>
</ab> 
<ab>
    <cit type="paraphrase" xml:id="prov5.spr66.2">
        <quote xml:id="prov5.1.spr66">ܢܟ̈ܣܐ܂ ܥܕܡܐ ܕܡܹܬܡܲܠܝܐ ܥܦܪܐ܂</quote>
        <note type="original-phrase">ܫܝܘܠ ܘܐܒܕܢܐ ܠܐ ܣܒܥܝܢ܂ ܗܟܢܐ ܐܦ ܥܝܢܗܘܢ ܕܒܢ̈ܝ ܐܢܫܐ ܠܐ ܣܒܥܐ</note>
        <bibl type="provided-by-editor" source="#Peshitta_Prov_Eccl_etc">Prov 27,20.</bibl>
    </cit>
</ab>
```

As is documented in the example, both `tei:cit` and `tei:quote` are connected with their respective counterpart via `@next` and `@xml:id`. Since the whole quote or paraphrase refers to the same referenced work, `tei:note` and `tei:bibl` only have to be set once in the last `tei:cit` element of the quote/paraphrase.

## Entities

### Persons and person-like entities

```HTML
<persName>Ahiqar</persName>
```

We are using persName for human beings and other impersonated entities like gods.

### Places

```HTML
<placeName>Assyria</placeName>
```

## Unsolved technical issues

### Displaying of the biblical quotations

A complete text passage in the text panel with a biblical reference cannot be marked when it contains more than a line. In such cases, its last line is marked only.

### False corrections by the copyist cannot be displayed

In some cases, the copyist made a wrong correction. In this phase, we were not able to mention the original form, the corrections by the copyist and our supplied form together. In such cases, we left the original form out.

### Missing space after a tagged word

In cases where ltr characters are used for editorial statments, a space is missing after the statement(cf. e.g. DFM 430, fol. 24v line 7 and 8: ‘unknown’, ‘unclear’).

### Gaps cannot be displayed

When the scribe let a gap (e.g. when he was not able to decipher a word) it cannot been displayed yet.

### Separation of a word

When a word is broken up on two lines, its togetherness is shown in this way:

```HTML
ܐܚܝܩܪ ( ܚܟܝ
 ܡܐ ܘܣܦܪܐ ) 
```

Occasionally, the last paranthesis is missing in some documents (e.g. Sachau, fol. 87r, line 14).

### Wrong displaying of vocal points

In some cases, the vocal points are not displayed as they have been transcribed. An example is 'ܘܟܸܬܒܸܿܬܼ' (taken from NDS 612, fol. 24r, line 11) which is displayed with an additional point below 'beth' (ܘܟܸܬܒܸܼܿܬܼ).

### Special case: The letter 'resh' with plural-marker

In some cases, when a 'resh' is combined with a plural-marker and an additional sign (e.g. a vowel-point), it is not illustrated as 'ܪ̈', but as a 'ܪ' with a pair of points (i.e. plural-marker) above it.
